@@ -96,7 +96,7 @@ gboolean netman_control_msg (NMApplet *nm, const char *cmd)
 {
     if (!g_strcmp0 (cmd, "menu"))
     {
-        if (nm->menu && gtk_widget_get_visible (nm->menu)) gtk_widget_hide (nm->menu);
+        if (nm->menu && gtk_widget_get_visible (nm->menu)) gtk_menu_popdown (GTK_MENU (nm->menu));
         else if (nm_client_get_nm_running (nm->nm_client)) status_icon_activate_cb (NULL, nm);
     }
 
